==> terminusdb-react-components-4.2.0.tgz: package/src/treeGraphComponent/detailsComponent/BaseInputElement.js <==
import React, {useState,useEffect,useRef} from 'react';
import PropTypes from 'prop-types'; 
import {HelpComponent} from './HelpComponent';
export const BaseInputElement = (props) => {

	const [value,setInputValue] = useState('')
	//const [autoFocus,setAutoFocus] = useState({})
	const inputElement = useRef(null);

	useEffect(() => {
        if(props.defaultValue!==value){
        	setInputValue(props.defaultValue)
        }
       
    },[props.defaultValue])

    useEffect(()=>{
       if(inputElement.current && props.defaultValue==="" && props.autoFocus===true && props.disabled!==true){
        	inputElement.current.focus();
        }
    },[inputElement.current,props.panelName])
	
	const onBlur = (evt)=>{
		if(typeof props.onBlur ==='function')props.onBlur(props.name,value);
	}

	const onChange = (evt) =>{
		setInputValue(evt.currentTarget.value)
	}

	const disabled = props.disabled === true ? {disabled:true} : {}
	//const autoFocus= props.disabled!==true && props.autoFocus === true ? {autoFocus:true} :{}

	return(
			<div className={props.groupClassName}>
			 	<div className="tdb__form__help">
	                 <label className={props.labelClassName} htmlFor={props.name}>{props.title}</label>
	                 <HelpComponent text={props.help}/>
                </div>
                <input 	ref={inputElement}
                		placeholder={props.placeholder} 
                		onBlur={onBlur} 
                		{...disabled} onChange={onChange} 
                		value={value} name={props.name} id={props.name}
                		className={props.inputClassName}></input>       
            	<span className="tdb__form__error">{props.itemError}</span>
            </div>

	)
}
//pattern="[0-9]{4}" required
BaseInputElement.propTypes = {
	  title:PropTypes.string,
	  defaultValue :PropTypes.string,
	  groupClassName:PropTypes.string,
	  inputClassName:PropTypes.string,
	  labelClassName:PropTypes.string,
	  name:PropTypes.string.isRequired,
	  onBlur:PropTypes.func,
	  disabled:PropTypes.bool,
	  placeholder:PropTypes.string
}

BaseInputElement.defaultProps = {
	  title:'',
	  defaultValue: '',
	  groupClassName:'tdb__form__group',
	  inputClassName:'tdb__form__element',
	  labelClassName:'tdb__form__label',
	  disabled:false,
	  placeholder:''
}

==> terminusdb-react-components-4.3.1.tgz: package/src/treeGraphComponent/detailsComponent/BaseInputElement.js <==
import React, {useState,useEffect,useRef} from 'react';
import PropTypes from 'prop-types'; 
import {HelpComponent} from './HelpComponent';
export const BaseInputElement = (props) => {

	const [value,setInputValue] = useState('')
	//const [autoFocus,setAutoFocus] = useState({})
	const inputElement = useRef(null);

	useEffect(() => {
        if(props.defaultValue!==value){
        	setInputValue(props.defaultValue)
        }
       
    },[props.defaultValue])

    useEffect(()=>{
       if(inputElement.current && props.defaultValue==="" && props.autoFocus===true && props.disabled!==true){
        	inputElement.current.focus();
        }
    },[inputElement.current,props.panelName])
	
	const onBlur = (evt)=>{
		let valueChecked=true
		if(typeof props.checkValue ==='function' ){
			valueChecked=props.checkValue(props.name,value)
		}
		if(typeof props.onBlur ==='function' && valueChecked)props.onBlur(props.name,value);
	}

	const onChange = (evt) =>{
		setInputValue(evt.currentTarget.value)
	}

	const disabled = props.disabled === true ? {disabled:true} : {}
	//const autoFocus= props.disabled!==true && props.autoFocus === true ? {autoFocus:true} :{}

	return(
			<div className={props.groupClassName}>
			 	<div className="tdb__form__help">
	                 <label className={props.labelClassName} htmlFor={props.name}>{props.title}</label>
	                 <HelpComponent text={props.help}/>
                </div>
                <input 	ref={inputElement}
                		placeholder={props.placeholder} 
                		onBlur={onBlur} 
                		{...disabled} onChange={onChange} 
                		value={value} name={props.name} id={props.name}
                		className={props.inputClassName}></input>       
            	<span className="tdb__form__error">{props.itemError}</span>
            </div>

	)
}
//pattern="[0-9]{4}" required
BaseInputElement.propTypes = {
	  title:PropTypes.string,
	  defaultValue :PropTypes.string,
	  groupClassName:PropTypes.string,
	  inputClassName:PropTypes.string,
	  labelClassName:PropTypes.string,
	  name:PropTypes.string.isRequired,
	  onBlur:PropTypes.func,
	  disabled:PropTypes.bool,
	  placeholder:PropTypes.string
}

BaseInputElement.defaultProps = {
	  title:'',
	  defaultValue: '',
	  groupClassName:'tdb__form__group',
	  inputClassName:'tdb__form__element',
	  labelClassName:'tdb__form__label',
	  disabled:false,
	  placeholder:''
}
